@@ -1,5 +1,6 @@
 from django.utils import timezone
 from django.test import TestCase
+from facebook_api.signals import facebook_api_post_fetch
 from facebook_pages.models import Page
 from facebook_pages.factories import PageFactory
 from models import PageStatistic
@@ -15,6 +16,7 @@ class FacebookPageStatisticTest(TestCase):
         self.assertEqual(PageStatistic.objects.count(), 0)
 
         page = PageFactory(graph_id=PAGE_FANS_ID, likes_count=10, talking_about_count=20)
+        facebook_api_post_fetch.send(sender=page.__class__, instance=page, created=True)
 
         self.assertEqual(PageStatistic.objects.count(), 1)
 
@@ -31,9 +33,3 @@ class FacebookPageStatisticTest(TestCase):
         self.assertTrue(stat.likes_count > 10)
         self.assertTrue(stat.talking_about_count > 20)
         self.assertTrue(isinstance(stat.updated_at, datetime))
-
-    def test_null_stats_test(self):
-
-        p = PageFactory(likes_count=None, talking_about_count=None)
-
-        self.assertEqual(PageStatistic.objects.count(), 0)
